@@ -91,7 +91,8 @@ class FfmpegProcess:
                                 eta = (file_duration - secs) / speed
                                 progress_handler(percentage, f"{speed}x", eta)
 
-            print(f"Done! Check out {ffmpeg_output_file} to see the FFmpeg output.")
+            progress_bar.close()
+            print(f"Done! Check out /{ffmpeg_output_file} to see the FFmpeg output.")
 
         except KeyboardInterrupt:
             progress_bar.close()
